@@ -1,8 +1,14 @@
 #!/usr/bin/env python3 
-import json,pickle,math,matplotlib,sys,os,string,subprocess
+import json,pickle,math,matplotlib,sys,os,string
+import shutil
 import numpy as np
 import pandas as pd
 from matplotlib import pyplot as plt
+import os
+if os.name == 'nt':
+    dirSep = '\\'
+else:
+    dirSep = '/'
 from plateypus.dataprocessing.miscFunctions import cleanUpFlowjoCSV,reorderDfByInputOrder
 from plateypus.dataprocessing import cytokineDataProcessing,singleCellDataProcessing,cellDataProcessing
 
@@ -13,13 +19,13 @@ plateColumnNumbers = list(range(1,25))
 
 def returnMultiIndex(sortedData,sortedFiles,dataType,folderName):
     if(dataType == 'cyt'):
-        newMultiIndex = cytokineDataProcessing.parseCytokineCSVHeaders(pd.read_csv('inputData/bulkCSVFiles/A1_'+dataType+'.csv').columns)
+        newMultiIndex = cytokineDataProcessing.parseCytokineCSVHeaders(pd.read_csv('inputData'+dirSep+'bulkCSVFiles'+dirSep+'A1_'+dataType+'.csv').columns)
     elif(dataType == 'cell'):
         if 'antibodyPanel-'+folderName+'.csv' in os.listdir('misc'):
-            panelData = pd.read_csv('misc/antibodyPanel-'+folderName+'.csv',)
-            newMultiIndex = cellDataProcessing.parseCellCSVHeaders(pd.read_csv('inputData/bulkCSVFiles/A1_'+dataType+'.csv').columns,panelData=panelData)
+            panelData = pd.read_csv('misc'+dirSep+'antibodyPanel-'+folderName+'.csv',)
+            newMultiIndex = cellDataProcessing.parseCellCSVHeaders(pd.read_csv('inputData'+dirSep+'bulkCSVFiles'+dirSep+'A1_'+dataType+'.csv').columns,panelData=panelData)
         else:
-            newMultiIndex = cellDataProcessing.parseCellCSVHeaders(pd.read_csv('inputData/bulkCSVFiles/A1_'+dataType+'.csv').columns)
+            newMultiIndex = cellDataProcessing.parseCellCSVHeaders(pd.read_csv('inputData'+dirSep+'bulkCSVFiles'+dirSep+'A1_'+dataType+'.csv').columns)
     elif(dataType == 'cytcorr'):
         newMultiIndex = []
     if dataType != 'singlecell':
@@ -27,9 +33,11 @@ def returnMultiIndex(sortedData,sortedFiles,dataType,folderName):
     else:
         return sortedFiles,newMultiIndex
 
-def decodeBarcodedPlates(experimentParameters,folderName,dataType):
-    path = 'inputData/bulkCSVFiles/'
+def decodeBarcodedPlates(experimentParameters,folderName,dataType,reverse):
+    path = 'inputData'+dirSep+'bulkCSVFiles'+dirSep
     barcodingDict = experimentParameters['barcodingDict']
+    bIndex  = 0
+    alignmentColumnOrder = []
     for barcodedPlate in barcodingDict:
         barcodedCSV = pd.read_csv(path+barcodedPlate+'_'+dataType+'.csv')
         for decodedPlate in barcodingDict[barcodedPlate]:
@@ -65,9 +73,19 @@ def decodeBarcodedPlates(experimentParameters,folderName,dataType):
                     newColumn = ' | '.join(['/'.join(populationsToKeep),populationStatisticSplit[1]])
                     newColumns.append(newColumn)
             decodedCSV.columns = newColumns
+            if bIndex == 0:
+                alignmentColumnOrder = decodedCSV.columns.tolist()
+            else:
+                if alignmentColumnOrder != decodedCSV.columns.tolist():
+                    #Realign columns
+                    newDecodedCSV = decodedCSV.iloc[:,:-1][alignmentColumnOrder[:-1]]
+                    decodedCSV.iloc[:,:-1] = newDecodedCSV.values
+                    decodedCSV.columns = alignmentColumnOrder
+            
             decodedCSV.to_csv(path+decodedPlate+'_'+dataType+'.csv',index=False)
-
-def unpackMultiplexedPlates(experimentParameters,folderName,dataType):
+            bIndex+=1
+        
+def unpackMultiplexedPlates(experimentParameters,folderName,dataType,reverse):
     #A1->A1,A2->A2,A3- >A1,B1->A4,B2->A3
     #1.1,1.3,1.5,3.1,3.3,3.5 -> A1; 1.2,1.4,1.6,3.2,3.4,3.6->A2; 2.1,2.3,3.5,4.1,4.3,4.5->A4; 2.2,2.4,2.6,4.2,4.4,4.6->A3
     #1-24
@@ -92,35 +110,80 @@ def unpackMultiplexedPlates(experimentParameters,folderName,dataType):
             plateIDConversionDict[multiplexedWellPos] = wellIDs
     #Specimen_001_A1_A01_001.fcs
     multiplexedPlateNames = experimentParameters['unpackingDict'].keys()
-    #sortedMultiplexedData,sortedMultiplexedFiles = cleanUpFlowjoCSV(multiplexedPlateNames,folderName,dataType)
-    for multiplexedPlateName in multiplexedPlateNames:
-        multiplexedWellPoses = experimentParameters['unpackingDict'][multiplexedPlateName]
-        with open('inputData/bulkCSVFiles/'+multiplexedPlateName+'_'+dataType+'.csv', 'r') as f:
-            multiplexedCSVLines = f.readlines()
-        for multiplexedWellPos in multiplexedWellPoses:
-            if multiplexedWellPos != '':
-                wellIDsInThisPos = plateIDConversionDict[multiplexedWellPos]
-                linesToMove = []
-                newCSVLines = []
-                for lineNum,line in enumerate(multiplexedCSVLines):
-                    if lineNum in [0,len(multiplexedCSVLines)-2,len(multiplexedCSVLines)-1]:
-                        newCSVLines.append(line)
-                    else:
-                        fileName = line.split(',')[0]
-                        wellID = fileName.split('_')[2]
-                        #Well ID is in pos or first line or last two lines
-                        if wellID in wellIDsInThisPos:
-                            #underscorePoses = [pos for pos, char in enumerate(line) if char == '_']
-                            newWellID = wellIDConversionDict[wellID]
+    #Unpacking
+    if not reverse:
+        for multiplexedPlateName in multiplexedPlateNames:
+            multiplexedWellPoses = experimentParameters['unpackingDict'][multiplexedPlateName]
+            with open('inputData'+dirSep+'bulkCSVFiles'+dirSep+multiplexedPlateName+'_'+dataType+'.csv', 'r') as f:
+                multiplexedCSVLines = f.readlines()
+            for multiplexedWellPos in multiplexedWellPoses:
+                if multiplexedWellPos != '':
+                    wellIDsInThisPos = plateIDConversionDict[multiplexedWellPos]
+                    linesToMove = []
+                    newCSVLines = []
+                    for lineNum,line in enumerate(multiplexedCSVLines):
+                        if lineNum in [0,len(multiplexedCSVLines)-2,len(multiplexedCSVLines)-1]:
+                            newCSVLines.append(line)
+                        else:
+                            #CyTEK Explorer
+                            if ' Well' in line:
+                                wellID = line.split(' ')[0]
+                            #FACSDiva
+                            else:
+                                fileName = line.split(',')[0]
+                                wellID = fileName.split('_')[2]
+                            #Well ID is in pos or first line or last two lines
+                            if wellID in wellIDsInThisPos:
+                                #underscorePoses = [pos for pos, char in enumerate(line) if char == '_']
+                                newWellID = wellIDConversionDict[wellID]
+                                newLine = line.replace(wellID,newWellID)
+                                newCSVLines.append(newLine)
+                    with open('inputData'+dirSep+'bulkCSVFiles'+dirSep+multiplexedWellPos+'_'+dataType+'.csv', 'w') as f:
+                        for item in newCSVLines:
+                            f.write("%s" % item)
+    #Repacking
+    else:
+        #Invert well conversion dictionary
+        for mpos,multiplexedPlateName in enumerate(experimentParameters['unpackingDict']):
+            newCSVLines = []
+            for mpos2,multiplexedWellPos in enumerate(experimentParameters['unpackingDict'][multiplexedPlateName]):
+                specificWellIDConversionDict = {}
+                for well in plateIDConversionDict[multiplexedWellPos]:
+                    specificWellIDConversionDict[well] = wellIDConversionDict[well]
+                invertedWellIDConversionDict = {v: k for k, v in specificWellIDConversionDict.items()}
+                if multiplexedWellPos != '':
+                    #Read unpacked csv, rename to name-unpacked.csv, delete old name (as repacked csv names can overlap with these)
+                    with open('inputData'+dirSep+'bulkCSVFiles'+dirSep+multiplexedWellPos+'_'+dataType+'.csv', 'r') as f:
+                        multiplexedCSVLines = f.readlines()
+                    shutil.copyfile('inputData'+dirSep+'bulkCSVFiles'+dirSep+multiplexedWellPos+'_'+dataType+'.csv','inputData'+dirSep+'bulkCSVFiles'+dirSep+multiplexedWellPos+'-unpacked_'+dataType+'.csv')
+                    os.remove('inputData'+dirSep+'bulkCSVFiles'+dirSep+multiplexedWellPos+'_'+dataType+'.csv')
+                    
+                    for lineNum,line in enumerate(multiplexedCSVLines):
+                        #If first plate to repack, use first line
+                        #If last plate to repack, use last 2 lines
+                        if lineNum in [0,len(multiplexedCSVLines)-2,len(multiplexedCSVLines)-1]:
+                            if (lineNum == 0 and mpos2 == 0) or (lineNum in [len(multiplexedCSVLines)-2,len(multiplexedCSVLines)-1] and mpos2 == len(experimentParameters['unpackingDict'][multiplexedPlateName])-1):
+                                newCSVLines.append(line)
+                        else:
+                            #CyTEK Explorer
+                            if ' Well' in line:
+                                wellID = line.split(' ')[0]
+                            #FACSDiva
+                            else:
+                                fileName = line.split(',')[0]
+                                wellID = fileName.split('_')[2]
+                            newWellID = invertedWellIDConversionDict[wellID]        
+                            #print(wellID+'->'+newWellID)
                             newLine = line.replace(wellID,newWellID)
                             newCSVLines.append(newLine)
-                with open('inputData/bulkCSVFiles/'+multiplexedWellPos+'_'+dataType+'.csv', 'w') as f:
-                    for item in newCSVLines:
-                        f.write("%s" % item)
+                     
+            with open('inputData'+dirSep+'bulkCSVFiles'+dirSep+multiplexedPlateName+'_'+dataType+'.csv', 'w') as f:
+                for item in newCSVLines:
+                    f.write("%s" % item)
 
 def performCommaCheck(fileName):
-    with open('inputData/bulkCSVFiles/'+fileName, 'r') as istr:
-        with open('inputData/bulkCSVFiles/temp-'+fileName, 'w') as ostr:
+    with open('inputData'+dirSep+'bulkCSVFiles'+dirSep+fileName, 'r') as istr:
+        with open('inputData'+dirSep+'bulkCSVFiles'+dirSep+'temp-'+fileName, 'w') as ostr:
             for line in istr:
                 if line[-1] != ',':
                     line = line.rstrip('\n') + ','
@@ -128,23 +191,23 @@ def performCommaCheck(fileName):
                 else:
                     line = line.rstrip('\n')
                     print(line, file=ostr)
-    subprocess.run(['rm','inputData/bulkCSVFiles/'+fileName])
-    subprocess.run(['mv','inputData/bulkCSVFiles/temp-'+fileName,'inputData/bulkCSVFiles/'+fileName])
+    os.remove('inputData'+dirSep+'bulkCSVFiles'+dirSep+fileName)
+    shutil.move('inputData'+dirSep+'bulkCSVFiles'+dirSep+'temp-'+fileName,'inputData'+dirSep+'bulkCSVFiles'+dirSep+fileName)
 
 def createBaseDataFrame(experimentParameters,folderName,experimentNumber,dataType,layoutDict):
     if experimentParameters['format'] == 'tube':
-        fullFormatDf = pickle.load(open('misc/tubeLayout-'+folderName+'-cell.pkl','rb'))
+        fullFormatDf = pickle.load(open('misc'+dirSep+'tubeLayout-'+folderName+'-cell.pkl','rb'))
         dfList = []
         levelLabelDict = experimentParameters['levelLabelDict']
-        for fileName in os.listdir('inputData/bulkCSVFiles/'):
+        for fileName in os.listdir('inputData'+dirSep+'bulkCSVFiles'+dirSep):
             if '.csv' in fileName:
                 performCommaCheck(fileName)
                 
                 bulkTubeCSVFileName = fileName
-                columnMultiIndexTuples = cellDataProcessing.parseCellCSVHeaders(pd.read_csv('inputData/bulkCSVFiles/'+bulkTubeCSVFileName).columns)
+                columnMultiIndexTuples = cellDataProcessing.parseCellCSVHeaders(pd.read_csv('inputData'+dirSep+'bulkCSVFiles'+dirSep+bulkTubeCSVFileName).columns)
                 columnMultiIndex = pd.MultiIndex.from_tuples(columnMultiIndexTuples,names=['CellType','Marker','Statistic'])
 
-                fullData = pd.read_csv('inputData/bulkCSVFiles/'+bulkTubeCSVFileName,header=0)
+                fullData = pd.read_csv('inputData'+dirSep+'bulkCSVFiles'+dirSep+bulkTubeCSVFileName,header=0)
                 if 'Unnamed' in fullData.columns[-1]:
                     data = fullData.iloc[:-2,1:-1].values
                 else:
@@ -161,9 +224,9 @@ def createBaseDataFrame(experimentParameters,folderName,experimentNumber,dataTyp
                 #Can use sample name file to assign time values
                 if 'sampleNameFile.xlsx' in os.listdir('misc') or 'sampleNameFile.csv' in os.listdir('misc'):
                     if 'sampleNameFile.xlsx' in os.listdir('misc'): 
-                        sampleNameDf = pd.read_excel('misc/sampleNameFile.xlsx')
+                        sampleNameDf = pd.read_excel('misc'+dirSep+'sampleNameFile.xlsx')
                     else:
-                        sampleNameDf = pd.read_csv('misc/sampleNameFile.csv')
+                        sampleNameDf = pd.read_csv('misc'+dirSep+'sampleNameFile.csv')
                     if 'Time' in sampleNameDf.columns:
                         for time in times:
                             timeIndices = []
@@ -202,11 +265,17 @@ def createBaseDataFrame(experimentParameters,folderName,experimentNumber,dataTyp
         fullExperimentDf = pd.concat(dfList)
     else:
         realDataType = dataType
-    
+        
+        #Reverse order; first decode 96 well barcoded plates, then repack the unbarcoded 96 well plates to a 384 well plate 
+        if experimentParameters['overallPlateDimensions'][0] == 16 and 'unpackingDict' in list(experimentParameters.keys()):
+            reverse = True
+        #Normal order; first decode 384 well barcoded plates, then unpack the unbarcoded 384 well plates to 96 well plates
+        else:
+            reverse = False
         if 'barcodingDict' in list(experimentParameters.keys()):
-            decodeBarcodedPlates(experimentParameters,folderName,dataType)
+            decodeBarcodedPlates(experimentParameters,folderName,dataType,reverse)
         if 'unpackingDict' in list(experimentParameters.keys()):
-            unpackMultiplexedPlates(experimentParameters,folderName,dataType)
+            unpackMultiplexedPlates(experimentParameters,folderName,dataType,reverse)
 
         #Legacy experiment parameter files compatibility
         if 'paired' in experimentParameters.keys():
@@ -309,14 +378,14 @@ def createBaseDataFrame(experimentParameters,folderName,experimentNumber,dataTyp
     return fullExperimentDf
 
 def convertDataFramesToExcel(folderName,secondPath,dataType,df):
-    writer = pd.ExcelWriter('outputData/excelFiles/excelFile-'+folderName+'-'+dataType+'.xlsx')
+    writer = pd.ExcelWriter('outputData'+dirSep+'excelFiles'+dirSep+'excelFile-'+folderName+'-'+dataType+'.xlsx')
     if dataType == 'cyt':
-        dfg = pickle.load(open('outputData/pickleFiles/cytokineGFIPickleFile-'+folderName+'.pkl','rb'))
-        dfc = pickle.load(open('outputData/pickleFiles/'+dataTypeDataFrameFileNames[dataType]+'-'+folderName+'.pkl','rb'))
+        dfg = pickle.load(open('outputData'+dirSep+'pickleFiles'+dirSep+'cytokineGFIPickleFile-'+folderName+'.pkl','rb'))
+        dfc = pickle.load(open('outputData'+dirSep+'pickleFiles'+dirSep+dataTypeDataFrameFileNames[dataType]+'-'+folderName+'.pkl','rb'))
         dfg.to_excel(writer,'MFI')
         dfc.to_excel(writer,'Concentration')
     elif dataType == 'killing':
-        dfk = pickle.load(open('outputData/pickleFiles/'+dataTypeDataFrameFileNames[dataType]+'-'+folderName+'.pkl','rb'))
+        dfk = pickle.load(open('outputData'+dirSep+'pickleFiles'+dirSep+dataTypeDataFrameFileNames[dataType]+'-'+folderName+'.pkl','rb'))
         dfk.to_excel(writer,'Killing Index')
     else:
         for statistic in list(pd.unique(df.index.get_level_values('Statistic'))):
@@ -326,7 +395,7 @@ def convertDataFramesToExcel(folderName,secondPath,dataType,df):
 
 def saveFinalDataFrames(folderName,secondPath,experimentNumber,dataType,fullExperimentDf,excel_data):
     fullExperimentDf = fullExperimentDf.astype(float)
-    with open('outputData/pickleFiles/'+dataTypeDataFrameFileNames[dataType]+'-'+folderName+'.pkl', "wb") as f:
+    with open('outputData'+dirSep+'pickleFiles'+dirSep+dataTypeDataFrameFileNames[dataType]+'-'+folderName+'.pkl', "wb") as f:
         pickle.dump(fullExperimentDf, f)
     convertDataFramesToExcel(folderName,secondPath,dataType,fullExperimentDf)
     print(fullExperimentDf)
