@@ -3,12 +3,17 @@ import pickle,os,json
 import pandas as pd
 import tkinter as tk
 import tkinter.ttk
+import os
+if os.name == 'nt':
+    dirSep = '\\'
+else:
+    dirSep = '/'
 import plateypus.dataprocessing.initialDataProcessing as idp
 import plateypus.dataprocessing.miscFunctions as mf
 import plateypus.plotting.facetPlotLibrary as fpl 
 import plateypus.plotting.interactiveGUIElements as ipe
 
-expParamDict = {'cyt':'cyt','cell':'cell','prolif':'cell','singlecell':'cell'}
+expParamDict = {'cyt':'cyt','cell':'cell','prolif':'cell','singlecell':'cell','killing':'killing'}
 
 #Get level names and values into an easily accessible dictionary
 def createLabelDict(df):
@@ -31,12 +36,10 @@ def createLabelDictWithExperimentParameters(df,experimentParameters):
             if 'allLevelValues' in list(experimentParameters.keys()):
                 experimentParameters['levelLabelDict'] = experimentParameters['allLevelValues']
             if levelName in experimentParameters['levelLabelDict'].keys():
-                #tempList = []
-                #for levelVal in experimentParameters['allLevelValues'][levelName]:
-                #    if levelVal in list(pd.unique(fulldf.index.get_level_values(levelName))):
-                #        tempList.append(levelVal)
-                #labelDict[levelName] = tempList 
-                labelDict[levelName] = experimentParameters['levelLabelDict'][levelName]
+                if len(experimentParameters['levelLabelDict'][levelName]) > 0:
+                    labelDict[levelName] = experimentParameters['levelLabelDict'][levelName]
+                else:
+                    labelDict[levelName] = list(pd.unique(fulldf.index.get_level_values(levelName)))
             else:
                 labelDict[levelName] = list(pd.unique(fulldf.index.get_level_values(levelName)))
     return labelDict
@@ -57,7 +60,7 @@ class checkUncheckAllButton(tk.Button):
 
 class PlotExperimentWindow(tk.Frame):
     def __init__(self, master,fName,sPage):
-        with open('misc/normalPlottingBool.pkl','wb') as f:
+        with open('misc'+dirSep+'normalPlottingBool.pkl','wb') as f:
             pickle.dump(True,f)
 
         global folderName,switchPage
@@ -80,22 +83,18 @@ class PlotExperimentWindow(tk.Frame):
         rb2b = tk.Radiobutton(mainWindow,text="Cell",padx = 20, variable=v2, value='cell')
         rb2c = tk.Radiobutton(mainWindow,text="Proliferation",padx = 20, variable=v2, value='prolif')
         rb2d = tk.Radiobutton(mainWindow,text="Single Cell",padx = 20, variable=v2, value='singlecell')
+        rb2e = tk.Radiobutton(mainWindow,text="Killing",padx = 20, variable=v2, value='killing')
         
-        v3 = tk.BooleanVar(value=False)
-        cb = tk.Checkbutton(mainWindow,padx = 20, variable=v3)
-
         l2.grid(row=0,column=0)
         rb2a.grid(row=1,column=0,sticky=tk.W)
         rb2b.grid(row=2,column=0,sticky=tk.W)
         rb2c.grid(row=3,column=0,sticky=tk.W)
         rb2d.grid(row=4,column=0,sticky=tk.W)
-        
-        l3 = tk.Label(mainWindow,text='Modified?').grid(row=0,column=1,sticky=tk.W)
-        cb.grid(row=1,column=1,sticky=tk.W)
+        rb2e.grid(row=5,column=0,sticky=tk.W)
         
         def collectInputs():
             global useModifiedDf
-            modified = v3.get()
+            modified = False 
             useModifiedDf = modified
             if modified:
                 modifiedString = '-modified'
@@ -105,12 +104,12 @@ class PlotExperimentWindow(tk.Frame):
             dataType = str(v2.get())
             global experimentDf
             if dataType != 'singlecell':
-                experimentDf = pd.read_pickle('outputData/pickleFiles/'+idp.dataTypeDataFrameFileNames[dataType]+'-'+folderName+modifiedString+'.pkl')
+                experimentDf = pd.read_pickle('outputData'+dirSep+'pickleFiles'+dirSep+idp.dataTypeDataFrameFileNames[dataType]+'-'+folderName+modifiedString+'.pkl')
             else:
-                if 'initialSingleCellDf-channel-'+folderName+modifiedString+'.pkl' in os.listdir('outputData/pickleFiles/'):
-                    experimentDf = pickle.load(open('outputData/pickleFiles/'+'initialSingleCellDf-channel-'+folderName+modifiedString+'.pkl','rb'))
+                if 'initialSingleCellDf-channel-'+folderName+modifiedString+'.pkl' in os.listdir('outputData'+dirSep+'pickleFiles'+dirSep):
+                    experimentDf = pickle.load(open('outputData'+dirSep+'pickleFiles'+dirSep+'initialSingleCellDf-channel-'+folderName+modifiedString+'.pkl','rb'))
                 else:
-                    experimentDf = pd.read_hdf('outputData/pickleFiles/'+'initialSingleCellDf-channel-'+folderName+modifiedString+'.h5', 'df')
+                    experimentDf = pd.read_hdf('outputData'+dirSep+'pickleFiles'+dirSep+'initialSingleCellDf-channel-'+folderName+modifiedString+'.h5', 'df')
                 if 'CellType' != experimentDf.index.names[0]:
                     experimentDf = pd.concat([experimentDf], keys=['TCells'], names=['CellType'])
             global trueLabelDict
@@ -122,7 +121,7 @@ class PlotExperimentWindow(tk.Frame):
                 if 'experimentParameters' in fn:
                     if expParamDict[dataType] in fn:
                         experimentParametersBool = True
-                        experimentParameters = json.load(open('misc/experimentParameters-'+folderName+'-'+expParamDict[dataType]+'.json','r'))
+                        experimentParameters = json.load(open('misc'+dirSep+'experimentParameters-'+folderName+'-'+expParamDict[dataType]+'.json','r'))
             if experimentParametersBool:
                 trueLabelDict = createLabelDictWithExperimentParameters(experimentDf,experimentParameters)
             else:
@@ -141,13 +140,13 @@ class PlotTypePage(tk.Frame):
     def __init__(self, master):
 
         if 'normalPlottingBool.pkl' in os.listdir('misc'):
-            normalPlottingBool = pickle.load(open('misc/normalPlottingBool.pkl','rb'))
+            normalPlottingBool = pickle.load(open('misc'+dirSep+'normalPlottingBool.pkl','rb'))
         else:
             normalPlottingBool = True
 
         if not normalPlottingBool:
             global useModifiedDf,dataType,experimentDf,trueLabelDict,folderName,switchPage
-            plottingParams = pickle.load(open('misc/plottingParams.pkl','rb'))
+            plottingParams = pickle.load(open('misc'+dirSep+'plottingParams.pkl','rb'))
             useModifiedDf = False
             dataType = 'cell'
             experimentDf = plottingParams['df']
@@ -441,7 +440,7 @@ def getDefaultAxisTitles():
 class plotElementsGUIPage(tk.Frame):
     def __init__(self, master):
         if 'experimentParameters-'+folderName+'-'+expParamDict[dataType]+'.json' in os.listdir('misc'):
-            experimentParameters = json.load(open('misc/experimentParameters-'+folderName+'-'+expParamDict[dataType]+'.json','r'))
+            experimentParameters = json.load(open('misc'+dirSep+'experimentParameters-'+folderName+'-'+expParamDict[dataType]+'.json','r'))
         else:
             tempDict = {}
             stackedDf = experimentDf.stack()
@@ -563,7 +562,20 @@ class plotElementsGUIPage(tk.Frame):
                 else:
                     plotSpecificDict['scaleToMode'] = False
                 plotSpecificDict['smoothing'] = int(ipe.getSliderValues(smoothingSliderList,['smoothing'])['smoothing'])
+            elif subPlotType == 'line':
+                ciType = ipe.getRadiobuttonValues(ciSelectionRadiobuttonVarsDict)['Error bar']
+                errType = ipe.getRadiobuttonValues(ciStyleSelectionRadiobuttonVarsDict)['Error bar style']
+                if ciType == 'st dev':
+                    plotSpecificDict['ci'] = 'sd'
+                elif ciType == 'conf int':
+                    plotSpecificDict['ci'] = 95
+
+                if errType == 'band' and ciType in ['st dev','conf int']:
+                    plotSpecificDict['err_style'] = 'band'
+                elif errType == 'bar' and ciType in ['st dev','conf int']:
+                    plotSpecificDict['err_style'] = 'bars'
             
+            print(plotSpecificDict)
             useModifiedDf = False
             sName = titleEntry.get()
             subsettedDfList,subsettedDfListTitles,figureLevels,levelValuesPlottedIndividually = fpl.produceSubsettedDataFrames(experimentDf.stack().to_frame('temp'),fullFigureLevelBooleanList,includeLevelValueList,self.tld)
@@ -642,7 +654,21 @@ class plotElementsGUIPage(tk.Frame):
             smoothnessWindow = tk.Frame(subPlotSpecificWindow)
             smoothnessWindow.grid(row=0,column=1,sticky=tk.N)
             smoothingSliderList = ipe.createParameterAdjustmentSliders(smoothnessWindow,['smoothing'],{'smoothing':[1,99,2,27]})
-        
+        elif subPlotType in ['line']:
+            #Scale to mode button
+            subPlotSpecificWindow = tk.Frame(self)
+            subPlotSpecificWindow.pack(side=tk.TOP,pady=10)
+            
+            ciSelectionWindow = tk.Frame(subPlotSpecificWindow)
+            ciSelectionWindow.grid(row=0,column=0,sticky=tk.N)
+            ciSelectionRadiobuttonList,ciSelectionRadiobuttonVarsDict = ipe.createParameterSelectionRadiobuttons(ciSelectionWindow,['Error bar'],{'Error bar':['none','st dev','conf int']}) 
+            ciSelectionRadiobuttonVarsDict['Error bar'].set('none')
+            
+            ciStyleSelectionWindow = tk.Frame(subPlotSpecificWindow)
+            ciStyleSelectionWindow.grid(row=0,column=1,sticky=tk.N)
+            ciStyleSelectionRadiobuttonList,ciStyleSelectionRadiobuttonVarsDict = ipe.createParameterSelectionRadiobuttons(ciStyleSelectionWindow,['Error bar style'],{'Error bar style':['bar','band']}) 
+            ciStyleSelectionRadiobuttonVarsDict['Error bar style'].set('bar')
+
         plotButtonWindow = tk.Frame(self)
         plotButtonWindow.pack(side=tk.TOP,pady=10)
         tk.Button(plotButtonWindow, text="Generate First Plot",command=lambda: collectInputs(False)).grid(row=0,column=0)
