@@ -1,10 +1,16 @@
 #!/usr/bin/env python3
-import pickle,os,json,math,subprocess
+import pickle,os,json,math,shutil
 import numpy as np
 import pandas as pd
 import tkinter as tk
+from tkinter import ttk
 from plateypus.setup.createTubeLayout import TubeLayoutPage 
 from plateypus.setup.createPlateLayout import BlankSelectionPage
+import os
+if os.name == 'nt':
+    dirSep = '\\'
+else:
+    dirSep = '/'
 
 experimentParameters = {}
 dataTypeDict = {'Cytokine':'cyt','Bulk/Single cell':'cell','Killing':'killing'}
@@ -50,7 +56,7 @@ class ExperimentSetupStartPage(tk.Frame):
         def experimentLayout():
             for dataType in dataTypeList:
                 if 'experimentParameters-'+folderName+'-'+dataType+'.json' in os.listdir('misc'):
-                    experimentParameters = json.load(open('misc/experimentParameters-'+folderName+'-'+dataType+'.json','r'))
+                    experimentParameters = json.load(open('misc'+dirSep+'experimentParameters-'+folderName+'-'+dataType+'.json','r'))
                     break
             if 'format' not in experimentParameters.keys():
                 experimentParameters['format'] = 'plate'
@@ -72,17 +78,17 @@ class ExperimentSetupStartPage(tk.Frame):
             else:
                 fcsFiles = []
                 
-                if 'A1_cell.csv' not in os.listdir('inputData/bulkCSVFiles/'):
-                    if len(os.listdir('inputData/fcsFiles')) > 1:
-                        for fcsName in os.listdir('inputData/fcsFiles'):
+                if 'A1_cell.csv' not in os.listdir('inputData'+dirSep+'bulkCSVFiles'+dirSep):
+                    if len(os.listdir('inputData'+dirSep+'fcsFiles')) > 1:
+                        for fcsName in os.listdir('inputData'+dirSep+'fcsFiles'):
                             if '.fcs' in fcsName:
                                 fcsFiles.append(fcsName)
                         if len(fcsFiles) == 0:
                             fcsFiles = ['                 ']
                     elif 'sampleNameFile.xlsx' in os.listdir('misc'):
-                        fcsFiles = list(pd.read_excel('misc/sampleNameFile.xlsx',header=0).iloc[:,0].values.ravel())
+                        fcsFiles = list(pd.read_excel('misc'+dirSep+'sampleNameFile.xlsx',header=0).iloc[:,0].values.ravel())
                 else:
-                    bulkStatFile = pd.read_csv('inputData/bulkCSVFiles/A1_cell.csv')
+                    bulkStatFile = pd.read_csv('inputData'+dirSep+'bulkCSVFiles'+dirSep+'A1_cell.csv')
                     for row in range(bulkStatFile.shape[0]):
                         if bulkStatFile.iloc[row,0] not in ['Mean','SD']:
                             fcsFiles.append(bulkStatFile.iloc[row,0])
@@ -155,7 +161,7 @@ class TubeExperimentParameterPage(tk.Frame):
         e1.grid(row=2,column=1)
         
         if 'sampleNameFile.xlsx' in os.listdir('misc'):
-            df = pd.read_excel('misc/sampleNameFile.xlsx')
+            df = pd.read_excel('misc'+dirSep+'sampleNameFile.xlsx')
             columns = []
             for column in df:
                 if column not in ['','FileName','Time']:
@@ -184,13 +190,35 @@ class PlateExperimentParameterPage(tk.Frame):
         mainWindow = tk.Frame(self)
         mainWindow.pack(side=tk.TOP,padx=10,pady=10)
         
+        l7 = tk.Label(mainWindow, text="Multiplexing Options:")
+        multiplex = tk.StringVar(value='None')
+        plateMultiplexVar = tk.BooleanVar() 
+        plateMultiplexVar2 = tk.BooleanVar() 
+        barcodeMultiplexVar = tk.BooleanVar() 
+        plateMultiplexCb = tk.Checkbutton(mainWindow,text='96->384 well',variable=plateMultiplexVar,onvalue=True,offvalue=False)
+        plateMultiplexCbRev = tk.Checkbutton(mainWindow,text='384->96 well',variable=plateMultiplexVar2,onvalue=True,offvalue=False)
+        plateMultiplexCbRev.config(state=tk.DISABLED)
+        plateMultiplexCb.config(state=tk.NORMAL)
+        barcodeMultiplexCb = tk.Checkbutton(mainWindow,text='Barcoding',variable=barcodeMultiplexVar,onvalue=True,offvalue=False)
+        barcodingNumberLabel = tk.Label(mainWindow,text='# plates per barcoded plate') 
+        barcodingNumberEntry = tk.Entry(mainWindow,width=4)
+
         v = tk.IntVar()
         v2 = tk.IntVar()
         v3 = tk.IntVar()
+        v4 = tk.IntVar()
+        
+        def disable():
+            if v3.get() == 384:
+                plateMultiplexCb.config(state=tk.DISABLED)
+                plateMultiplexCbRev.config(state=tk.NORMAL)
+            else:
+                plateMultiplexCbRev.config(state=tk.DISABLED)
+                plateMultiplexCb.config(state=tk.NORMAL)
 
         l3 = tk.Label(mainWindow, text="""What format were the samples collected in?:""")
-        rb3a = tk.Radiobutton(mainWindow, text="96 well plate",padx = 20, variable=v3, value=96)
-        rb3b = tk.Radiobutton(mainWindow,text="384 well plate",padx = 20, variable=v3, value=384)
+        rb3a = tk.Radiobutton(mainWindow, text="96 well plate",padx = 20, variable=v3, value=96,command=lambda: disable())
+        rb3b = tk.Radiobutton(mainWindow,text="384 well plate",padx = 20, variable=v3, value=384,command=lambda: disable())
         l3.grid(row=0,column=0)
         rb3a.grid(row=0,column=1)
         rb3b.grid(row=0,column=2)
@@ -206,17 +234,9 @@ class PlateExperimentParameterPage(tk.Frame):
         l6.grid(row=3,column=0)
         e2.grid(row=3,column=1)
         
-        l7 = tk.Label(mainWindow, text="Multiplexing Options:")
-        multiplex = tk.StringVar(value='None')
-        plateMultiplexVar = tk.BooleanVar() 
-        barcodeMultiplexVar = tk.BooleanVar() 
-        plateMultiplexCb = tk.Checkbutton(mainWindow,text='96->384 well',variable=plateMultiplexVar,onvalue=True,offvalue=False)
-        barcodeMultiplexCb = tk.Checkbutton(mainWindow,text='Barcoding',variable=barcodeMultiplexVar,onvalue=True,offvalue=False)
-        barcodingNumberLabel = tk.Label(mainWindow,text='# plates per barcoded plate') 
-        barcodingNumberEntry = tk.Entry(mainWindow,width=4)
-
         l7.grid(row=4,column=0)
         plateMultiplexCb.grid(row=4,column=1)
+        plateMultiplexCbRev.grid(row=5,column=1)
         barcodeMultiplexCb.grid(row=4,column=2)
         barcodingNumberLabel.grid(row=4,column=3)
         barcodingNumberEntry.grid(row=4,column=4)
@@ -234,17 +254,23 @@ class PlateExperimentParameterPage(tk.Frame):
             else:
                 experimentParameters['overallPlateDimensions'] = [8,12]
             
-            if plateMultiplexVar.get() and barcodeMultiplexVar.get():
+            if (plateMultiplexVar.get() or plateMultiplexVar2.get()) and barcodeMultiplexVar.get():
                 multiplexingOption = '96->384 well + Barcoding'
-                numberOfBarcodes = int(barcodingNumberEntry.get())
+                numberOfBarcodes = barcodingNumberEntry.get()
             else:
-                if plateMultiplexVar.get():
+                if plateMultiplexVar.get() or plateMultiplexVar2.get():
                     multiplexingOption = '96->384 well'
+                    numberOfBarcodes = 1
                 elif barcodeMultiplexVar.get():
                     multiplexingOption = 'Barcoding'
-                    numberOfBarcodes = int(barcodingNumberEntry.get())
+                    numberOfBarcodes = barcodingNumberEntry.get()
                 else:
                     multiplexingOption = 'None'
+                    numberOfBarcodes = 1
+            if ',' in barcodingNumberEntry.get():
+                numberOfBarcodes = list(map(int,numberOfBarcodes.split(',')))
+            else:
+                numberOfBarcodes = [int(numberOfBarcodes)]
             global globalMultiplexingVar
             globalMultiplexingVar = multiplexingOption
             experimentParameters['multiplexingOption'] = multiplexingOption
@@ -268,21 +294,11 @@ class BarcodingPage(tk.Frame):
     def __init__(self, master,mpo,nb):
         tk.Frame.__init__(self, master)
         multiplexingOption = mpo
-        numberOfBarcodedPlates = nb
-        numPl = experimentParameters['numPlates'] 
-        numberOfBarcodes = math.ceil(np.log2(nb))
         BarcodingWindow = tk.Frame(self)
         BarcodingWindow.pack()
-        if multiplexingOption == '96->384 well + Barcoding':
-            maxNumBarcoded = math.ceil(experimentParameters['numPlates'] / 4 / numberOfBarcodedPlates)
-            totalPlatesPerBarcodedPlate = 4*numberOfBarcodedPlates
-            plateSkip = 4
-        else:
-            maxNumBarcoded = math.ceil(experimentParameters['numPlates'] / numberOfBarcodedPlates)
-            totalPlatesPerBarcodedPlate = numberOfBarcodedPlates
-            plateSkip = 1
-        l1 = tk.Label(BarcodingWindow,text='Barcoded Plate Name:')
-        l2 = tk.Label(BarcodingWindow,text='Plate Name:')
+        numPl = experimentParameters['numPlates'] 
+        
+        numberOfBarcodes = math.ceil(np.log2(max(nb)))
         entryBarcodeLabelList = []
         for barcode in range(numberOfBarcodes):
             e = tk.Entry(BarcodingWindow,width=8)
@@ -290,41 +306,109 @@ class BarcodingPage(tk.Frame):
             e.insert(tk.END, 'Barcode '+str(barcode+1))
             entryBarcodeLabelList.append(e)
             #tk.Label(BarcodingWindow,text='Barcode '+str(barcode+1)).grid(row=0,column=2+barcode)
+        
+        if len(nb) == 1:
+            numberOfBarcodedPlates = nb[0]
+            if multiplexingOption == '96->384 well + Barcoding':
+                if experimentParameters['overallPlateDimensions'][0] == 8: 
+                    maxNumBarcoded = math.ceil(experimentParameters['numPlates'] / 4 / numberOfBarcodedPlates)
+                    totalPlatesPerBarcodedPlate = 4*numberOfBarcodedPlates
+                    plateSkip = 4
+                #384->96
+                else: 
+                    maxNumBarcoded = math.ceil(4*experimentParameters['numPlates'] / numberOfBarcodedPlates)
+                    totalPlatesPerBarcodedPlate = numberOfBarcodedPlates
+                    plateSkip = 1 
+            else:
+                maxNumBarcoded = math.ceil(experimentParameters['numPlates'] / numberOfBarcodedPlates)
+                totalPlatesPerBarcodedPlate = numberOfBarcodedPlates
+                plateSkip = 1
+            allIndividualPlateEntryList = []
+            combinedPlateBarcodingVarList,combinedEntryList = [],[]
+            for combinedPlateNum in range(maxNumBarcoded):
+                combinedEntry = tk.Entry(BarcodingWindow,width=8)
+                combinedEntry.insert(tk.END, 'A'+str(combinedPlateNum*totalPlatesPerBarcodedPlate+1)+'-'+str((combinedPlateNum+1)*totalPlatesPerBarcodedPlate))
+                plateStart = combinedPlateNum*totalPlatesPerBarcodedPlate+1
+                plateEnd = (combinedPlateNum+1)*totalPlatesPerBarcodedPlate
+                allPlateIndices = list(range(plateStart,plateEnd+2,plateSkip))
+                combinedEntry.grid(row=combinedPlateNum*numberOfBarcodedPlates+1,column=0)
+                plateBarcodingVarList,plateEntryList = [],[]
+                for plateNum in range(numberOfBarcodedPlates):
+                    if plateNum == numberOfBarcodedPlates-1:
+                        padvar = 10 
+                    else:
+                        padvar = 0
+                    plateEntry = tk.Entry(BarcodingWindow,width=8)
+                    if plateSkip == 4:
+                        plateEntry.insert(tk.END, 'A'+str(allPlateIndices[plateNum])+'-'+str(allPlateIndices[plateNum+1]-1))
+                    else:
+                        plateEntry.insert(tk.END, 'A'+str(allPlateIndices[plateNum]))
+                    plateEntry.grid(row=combinedPlateNum*numberOfBarcodedPlates+plateNum+1,column=1,pady=(0,padvar))
+                    barcodingCbList,barcodingVarList = [],[]
+                    for barcodeNum in range(numberOfBarcodes):
+                        barcodeVar = tk.BooleanVar()
+                        barcodeCb = tk.Checkbutton(BarcodingWindow,text='',variable=barcodeVar,onvalue=True,offvalue=False)
+                        barcodeCb.grid(row=combinedPlateNum*numberOfBarcodedPlates+plateNum+1,column=2+barcodeNum,pady=(0,padvar))
+                        barcodingCbList.append(barcodeCb)
+                        barcodingVarList.append(barcodeVar)
+                    plateBarcodingVarList.append(barcodingVarList)
+                    plateEntryList.append(plateEntry)
+                combinedPlateBarcodingVarList.append(plateBarcodingVarList)
+                combinedEntryList.append(combinedEntry)
+                allIndividualPlateEntryList.append(plateEntryList)
+        else:
+            if multiplexingOption == '96->384 well + Barcoding':
+                if experimentParameters['overallPlateDimensions'][0] == 8: 
+                    plateSkip = 4
+                #384->96
+                else: 
+                    plateSkip = 1 
+            else:
+                plateSkip = 1
+            allIndividualPlateEntryList = []
+            combinedPlateBarcodingVarList,combinedEntryList = [],[]
+            for elem,numberOfBarcodedPlates in enumerate(nb):
+                summedPlateNums = sum(nb[:elem+1])
+                plateEnd = plateSkip*summedPlateNums
+                if elem == 0:
+                    plateStart = 1
+                    plateRow = 1
+                else:
+                    plateStart = sum(nb[:elem])*plateSkip + 1
+                    plateRow = sum(nb[:elem]) + 1
+                combinedEntry = tk.Entry(BarcodingWindow,width=8)
+                combinedEntry.insert(tk.END, 'A'+str(plateStart)+'-'+str(plateEnd))
+                combinedEntry.grid(row=plateRow,column=0)
+                allPlateIndices = list(range(plateStart,plateEnd+2,plateSkip))
+                plateBarcodingVarList,plateEntryList = [],[]
+                for plateNum in range(numberOfBarcodedPlates):
+                    if plateNum == numberOfBarcodedPlates-1 and plateNum != 0:
+                        padvar = 10 
+                    else:
+                        padvar = 0
+                    plateEntry = tk.Entry(BarcodingWindow,width=8)
+                    if plateSkip == 4:
+                        plateEntry.insert(tk.END, 'A'+str(allPlateIndices[plateNum])+'-'+str(allPlateIndices[plateNum+1]-1))
+                    else:
+                        plateEntry.insert(tk.END, 'A'+str(allPlateIndices[plateNum]))
+                    plateEntry.grid(row=plateRow+plateNum,column=1,pady=(0,padvar))
+                    barcodingCbList,barcodingVarList = [],[]
+                    for barcodeNum in range(numberOfBarcodes):
+                        barcodeVar = tk.BooleanVar()
+                        barcodeCb = tk.Checkbutton(BarcodingWindow,text='',variable=barcodeVar,onvalue=True,offvalue=False)
+                        barcodeCb.grid(row=plateRow+plateNum,column=2+barcodeNum,pady=(0,padvar))
+                        barcodingCbList.append(barcodeCb)
+                        barcodingVarList.append(barcodeVar)
+                    plateBarcodingVarList.append(barcodingVarList)
+                    plateEntryList.append(plateEntry)
+                combinedPlateBarcodingVarList.append(plateBarcodingVarList)
+                combinedEntryList.append(combinedEntry)
+                allIndividualPlateEntryList.append(plateEntryList)
+
+        l1 = tk.Label(BarcodingWindow,text='Barcoded Plate Name:')
+        l2 = tk.Label(BarcodingWindow,text='Plate Name:')
         l1.grid(row=0,column=0)
         l2.grid(row=0,column=1)
-        allIndividualPlateEntryList = []
-        combinedPlateBarcodingVarList,combinedEntryList = [],[]
-        for combinedPlateNum in range(maxNumBarcoded):
-            combinedEntry = tk.Entry(BarcodingWindow,width=8)
-            combinedEntry.insert(tk.END, 'A'+str(combinedPlateNum*totalPlatesPerBarcodedPlate+1)+'-'+str((combinedPlateNum+1)*totalPlatesPerBarcodedPlate))
-            plateStart = combinedPlateNum*totalPlatesPerBarcodedPlate+1
-            plateEnd = (combinedPlateNum+1)*totalPlatesPerBarcodedPlate
-            allPlateIndices = list(range(plateStart,plateEnd+2,plateSkip))
-            combinedEntry.grid(row=combinedPlateNum*numberOfBarcodedPlates+1,column=0)
-            plateBarcodingVarList,plateEntryList = [],[]
-            for plateNum in range(numberOfBarcodedPlates):
-                if plateNum == numberOfBarcodedPlates-1:
-                    padvar = 10 
-                else:
-                    padvar = 0
-                plateEntry = tk.Entry(BarcodingWindow,width=8)
-                if plateSkip == 4:
-                    plateEntry.insert(tk.END, 'A'+str(allPlateIndices[plateNum])+'-'+str(allPlateIndices[plateNum+1]-1))
-                else:
-                    plateEntry.insert(tk.END, 'A'+str(allPlateIndices[plateNum]))
-                plateEntry.grid(row=combinedPlateNum*numberOfBarcodedPlates+plateNum+1,column=1,pady=(0,padvar))
-                barcodingCbList,barcodingVarList = [],[]
-                for barcodeNum in range(numberOfBarcodes):
-                    barcodeVar = tk.BooleanVar()
-                    barcodeCb = tk.Checkbutton(BarcodingWindow,text='',variable=barcodeVar,onvalue=True,offvalue=False)
-                    barcodeCb.grid(row=combinedPlateNum*numberOfBarcodedPlates+plateNum+1,column=2+barcodeNum,pady=(0,padvar))
-                    barcodingCbList.append(barcodeCb)
-                    barcodingVarList.append(barcodeVar)
-                plateBarcodingVarList.append(barcodingVarList)
-                plateEntryList.append(plateEntry)
-            combinedPlateBarcodingVarList.append(plateBarcodingVarList)
-            combinedEntryList.append(combinedEntry)
-            allIndividualPlateEntryList.append(plateEntryList)
 
         def collectInputs():
             barcodingDict = {}
@@ -358,7 +442,7 @@ class BarcodingPage(tk.Frame):
                 master.switch_frame(MultiplexingPage,multiplexingOption)
             else:
                 master.switch_frame(allLevelNamePage,folderName)
-
+        
         buttonWindow = tk.Frame(self)
         buttonWindow.pack(side=tk.TOP,pady=10)
 
@@ -373,23 +457,44 @@ class MultiplexingPage(tk.Frame):
         Well384ConversionWindow = tk.Frame(self)
         Well384ConversionWindow.pack()
         
-        maxNum384Plates = math.ceil(experimentParameters['numPlates'] / 4)
+        reverse = False
+        if multiplexingOption == '96->384 well + Barcoding':
+            if experimentParameters['overallPlateDimensions'][0] == 16: 
+                reverse = True
+
+        if not reverse:
+            maxNum384Plates = math.ceil(experimentParameters['numPlates'] / 4)
+        else:
+            maxNum384Plates = math.ceil(experimentParameters['numPlates'])
         Unpacking384PlateNameList = []
         Unpacking384List = []
         l1 = tk.Label(Well384ConversionWindow,text='Combined Plate Names: ')
         l1.grid(row=0,column=0)
+        l2 = tk.Label(Well384ConversionWindow,text='Separated Plate Names: ')
+        l2.grid(row=1,column=0)
+        ttk.Separator().place(x=0, y=27, relwidth=1)
+        ttk.Separator().place(x=157, y=0, relheight=0.65)
         for plateNum in range(maxNum384Plates):
             e1 = tk.Entry(Well384ConversionWindow,width=7)
-            e1.insert(tk.END, 'A'+str(plateNum*4+1)+'-'+str((plateNum+1)*4))
+            if not reverse:
+                e1.insert(tk.END, 'A'+str(plateNum*4+1)+'-'+str((plateNum+1)*4))
+            else:
+                e1.insert(tk.END, 'A'+str(plateNum+1))
             e1.grid(row=0,column=plateNum*2+1)
             Unpacking384PlateNameList.append(e1)
             UnpackingWellPosList = []
             wellIndexList = [0,1,3,2]
             wellIndex = 0
+            ttk.Separator().place(x=317+plateNum*160, y=0, relheight=0.65)
+            pN = 0
             for wellUnpackingRow in range(2):
                 for wellUnpackingCol in range(2):
                     e2 = tk.Entry(Well384ConversionWindow,width=7)
-                    e2.insert(tk.END, 'A'+str((plateNum*4)+wellIndexList[wellIndex]+1))
+                    if pN < experimentParameters['numPlates']:
+                        e2.insert(tk.END, 'A'+str((plateNum*4)+wellIndexList[wellIndex]+1))
+                        pN+=1
+                    else:
+                        e2.insert(tk.END, '')
                     if wellUnpackingCol == 1:
                         padvar = 5
                     else:
@@ -435,7 +540,7 @@ class allLevelNamePage(tk.Frame):
         lt3 = tk.Label(mainWindow, text="Numeric?").grid(row=0,column=3)
         
         if 'sampleNameFile.xlsx' in os.listdir('misc'):
-            df = pd.read_excel('misc/sampleNameFile.xlsx')
+            df = pd.read_excel('misc'+dirSep+'sampleNameFile.xlsx')
             levels = []
             levelValueNums = []
             for level in df.columns:
@@ -536,7 +641,7 @@ class columnLevelValuesPage(tk.Frame):
             lt1 = tk.Label(mainWindow, text='Level Value '+str(col),width=10).grid(row=int((col-1)/col_wrap)*2,column=((col-1)%col_wrap)+1)
         entryList = []
         if 'sampleNameFile.xlsx' in os.listdir('misc'):
-            df = pd.read_excel('misc/sampleNameFile.xlsx')
+            df = pd.read_excel('misc'+dirSep+'sampleNameFile.xlsx')
             if 'Time' in df.columns:
                 times = list(map(float,list(pd.unique(df['Time']))))
                 sortedTimes = list(map(str,sorted(times)))
@@ -592,7 +697,7 @@ class conditionLevelValuesPage(tk.Frame):
         labelList = experimentParameters['conditionLevelNames']
         rowNum = 0
         if 'sampleNameFile.xlsx' in os.listdir('misc'):
-            df = pd.read_excel('misc/sampleNameFile.xlsx')
+            df = pd.read_excel('misc'+dirSep+'sampleNameFile.xlsx')
         for conditionLevelNumber in range(numConditionLevels):
             if 'sampleNameFile.xlsx' in os.listdir('misc'):
                 j = 0
@@ -638,7 +743,7 @@ class conditionLevelValuesPage(tk.Frame):
                     shortenedExperimentParameters[keyToKeep] = experimentParameters[keyToKeep]
             shortenedExperimentParameters['levelLabelDict'] = experimentParameters['allLevelValues']
             for dataType in dataTypeList:
-                with open('misc/experimentParameters-'+folderName+'-'+dataType+'.json', 'w') as fp:
+                with open('misc'+dirSep+'experimentParameters-'+folderName+'-'+dataType+'.json', 'w') as fp:
                     json.dump(shortenedExperimentParameters, fp)
             #{"A1-12": {"A1-4": ["Barcode 1-", "Barcode 2-"], "A5-8": ["Barcode 1+", "Barcode 2-"], "A9-12": ["Barcode 1-", "Barcode 2+"]}}
             #{"A1-4": ["A1", "A2", "A4", "A3"], "A5-8": ["A5", "A6", "A8", "A7"], "A9-12": ["A9", "A10", "A12", "A11"]}
@@ -646,21 +751,21 @@ class conditionLevelValuesPage(tk.Frame):
                 #Both
                 if '+' in globalMultiplexingVar:
                     for plate in experimentParameters['barcodingDict']:
-                        if plate not in os.listdir('inputData/singleCellCSVFiles/'):
-                            subprocess.run(['mkdir','inputData/singleCellCSVFiles/'+plate])
+                        if plate not in os.listdir('inputData'+dirSep+'singleCellCSVFiles'+dirSep):
+                            os.mkdir('inputData'+dirSep+'singleCellCSVFiles'+dirSep+plate)
                 else:
                     if 'Barcoding' in globalMultiplexingVar:
                         for plate in experimentParameters['barcodingDict']:
-                            if plate not in os.listdir('inputData/singleCellCSVFiles/'):
-                                subprocess.run(['mkdir','inputData/singleCellCSVFiles/'+plate])
+                            if plate not in os.listdir('inputData'+dirSep+'singleCellCSVFiles'+dirSep):
+                                os.mkdir('inputData'+dirSep+'singleCellCSVFiles'+dirSep+plate)
                     elif '96' in globalMultiplexingVar:
                         for plate in experimentParameters['unpackingDict']:
-                            if plate not in os.listdir('inputData/singleCellCSVFiles/'):
-                                subprocess.run(['mkdir','inputData/singleCellCSVFiles/'+plate])
+                            if plate not in os.listdir('inputData'+dirSep+'singleCellCSVFiles'+dirSep):
+                                os.mkdir('inputData'+dirSep+'singleCellCSVFiles'+dirSep+plate)
                     else:
                         for plateNum in range(1,experimentParameters['numPlates']+1):
-                            if 'A'+str(plateNum) not in os.listdir('inputData/singleCellCSVFiles/'):
-                                subprocess.run(['mkdir','inputData/singleCellCSVFiles/A'+str(plateNum)])
+                            if 'A'+str(plateNum) not in os.listdir('inputData'+dirSep+'singleCellCSVFiles'+dirSep):
+                                os.mkdir('inputData'+dirSep+'singleCellCSVFiles'+dirSep+'A'+str(plateNum))
             master.switch_frame(ExperimentSetupStartPage,folderName,backPage)
 
         buttonWindow = tk.Frame(self)
